@@ -11,7 +11,7 @@
 # to plot the points.
 # 
 # \itemize{
-#   \item x: x position (required)
+#   \item \code{x}:x position (required)
 # }
 # 
 # These can be specified in the plot defaults (see \code{\link{ggplot}}) or
@@ -23,8 +23,9 @@
 # Other options:
 # 
 # \itemize{
-#   \item breaks: breaks argument passed to \code{\link{hist}}
-#   \item scale: scale argument passed to \code{\link{hist}}
+#   \item \code{breaks}:breaks argument passed to \code{\link{hist}}
+#   \item \code{scale}:scale argument passed to \code{\link{hist}}
+# 	\item any other aesthetic setting passed on to \code{\link{ggrect}}
 # }
 # 
 # @arguments the plot object to modify
@@ -34,14 +35,22 @@
 # @keyword hplot
 #X m <- ggplot(movies, aesthetics=list(x=rating))
 #X gghistogram(m)
-gghistogram <- function(plot = .PLOT, aesthetics=list(), ..., data=plot$data) {
+#X gghistogram(m, breaks=100)
+#X qplot(length, data=movies, type="histogram")
+#X qplot(log(length), data=movies, type="histogram")
+#X m <- ggplot(movies, Action ~ Comedy, aesthetics=list(x=rating), margins=TRUE)
+#X gghistogram(m)
+#X gghistogram(m, scale="freq")
+#X gghistogram(m, colour="darkgreen", fill="white") 
+gghistogram <- function(plot = .PLOT, aesthetics=list(), scale="prob", ..., data=NULL) {
 	plot <- pscontinuous(plot, "y", range=c(0,NA), expand=c(0.05,0))
 	plot <- pscontinuous(plot, "x", expand=c(0.15, 0))
-	plot$ylabel <- "Density"
+	
+	plot$ylabel <- if (scale == "prob") "Density" else "Frequency"
 
-	gg_add("histogram", plot, aesthetics, ..., data=data)
+	gg_add("histogram", plot, aesthetics, scale=scale, ..., data=data)
 }
-pre_histogram <- function(data, breaks="Sturges", scale="prob", ...) {
+pre_histogram <- function(data, breaks=20, scale="prob", ...) {
 	h <- hist(data$x, breaks=breaks, freq=FALSE, plot=FALSE, ...)
 
 	if (is.character(scale) && scale == "prob") {
@@ -55,7 +64,7 @@ pre_histogram <- function(data, breaks="Sturges", scale="prob", ...) {
 	data.frame(y = y, x=h$breaks[-1], width = diff(h$breaks), height=y)
 }
 grob_histogram <- function(aesthetics, ...) {
-	grob_rect(aesthetics, justification=c("right", "top"), colour="grey")
+	grob_rect(aesthetics, justification=c("right", "top"), ...)
 }
 
 # Grob function: quantiles
@@ -67,8 +76,8 @@ grob_histogram <- function(aesthetics, ...) {
 # Aesthetic mappings that this grob function understands:
 #
 # \itemize{
-#   \item x: x position (required)
-#   \item y: y position (required)
+#   \item \code{x}:x position (required)
+#   \item \code{y}:y position (required)
 # }
 # 
 # These can be specified in the plot defaults (see \code{\link{ggplot}}) or
@@ -80,9 +89,8 @@ grob_histogram <- function(aesthetics, ...) {
 # Other options:
 # 
 # \itemize{
-#   \item quantiles: quantiles to display
-#   \item formula: formula to use in quantile regression
-#   \item colour: colour of lines
+#   \item \code{quantiles}:quantiles to display
+#   \item \code{formula}:formula to use in quantile regression
 # }
 # 
 # @arguments the plot object to modify
@@ -93,10 +101,11 @@ grob_histogram <- function(aesthetics, ...) {
 # @seealso \code{\link[quantreg]{rq}} for the code used to fit the quantile regression
 #X m <- ggplot(movies, aesthetics=list(y=length, x=rating))
 #X ggquantile(gghexagon(m))
-ggquantile <- function(plot = .PLOT, aesthetics=list(), ..., data=plot$data) {
+#X ggquantile(gghexagon(m), colour="green")
+ggquantile <- function(plot = .PLOT, aesthetics=list(), ..., data=NULL) {
 	gg_add("quantile", plot, aesthetics, ..., data=data)
 }
-grob_quantile <- function(aesthetics, quantiles=c(0.05, 0.25, 0.5, 0.75, 0.95), formula=y ~ splines::ns(x, 5), colour="blue", ...) {
+grob_quantile <- function(aesthetics, quantiles=c(0.05, 0.25, 0.5, 0.75, 0.95), formula=y ~ splines::ns(x, 5), ...) {
 	if (!require(quantreg, quietly=TRUE)) stop("You need to install the quantreg package!")
 	
 	xseq <- seq(min(aesthetics$x, na.rm=TRUE), max(aesthetics$x, na.rm=TRUE), length=30)
@@ -105,9 +114,8 @@ grob_quantile <- function(aesthetics, quantiles=c(0.05, 0.25, 0.5, 0.75, 0.95),
 	yhats <- predict(model, data.frame(x=xseq))
 	qs <- data.frame(y = as.vector(yhats), x = xseq, id = rep(quantiles, each=length(xseq)))
 	qs$size <- (0.5 - abs(0.5 - qs$id))*5 + 0.5
-	qs$colour <- colour
 	
-	grob_path(qs)
+	grob_path(qs, ...)
 }
 
 # Grob function: boxplot
@@ -116,8 +124,8 @@ grob_quantile <- function(aesthetics, quantiles=c(0.05, 0.25, 0.5, 0.75, 0.95),
 # Aesthetic mappings that this grob function understands:
 #
 # \itemize{
-#   \item x: x position (required)
-#   \item y: y position (required)
+#   \item \code{x}:x position (required)
+#   \item \code{y}:y position (required)
 # }
 # 
 # These can be specified in the plot defaults (see \code{\link{ggplot}}) or
@@ -129,7 +137,7 @@ grob_quantile <- function(aesthetics, quantiles=c(0.05, 0.25, 0.5, 0.75, 0.95),
 # Other options:
 # 
 # \itemize{
-#   \item breaks: how to break up the x axis
+#   \item \code{breaks}:how to break up the x axis
 #   \item other arguments passed \code{\link{boxplot}}
 # }
 # 
@@ -139,31 +147,37 @@ grob_quantile <- function(aesthetics, quantiles=c(0.05, 0.25, 0.5, 0.75, 0.95),
 # @arguments data source, if not specified the plot default will be used
 # @keyword hplot
 # @seealso \code{\link{ggquantile}} for a continuous analogue of the boxplot
-#X p <- ggplot(mtcars, aesthetics=list(y=mpg, x=cyl))
+#X p <- ggplot(mtcars, aesthetics=list(y=mpg, x=factor(cyl)))
 #X ggpoint(p)
 #X ggboxplot(p)
+#X ggboxplot(p, fill="pink", colour="green")
 #X ggpoint(ggboxplot(p))
-ggboxplot <- function(plot = .PLOT, aesthetics=list(), ..., data=plot$data) {
+ggboxplot <- function(plot = .PLOT, aesthetics=list(), ..., data=NULL) {
 	gg_add("boxplot", plot, aesthetics, ..., data=data)
 }
 grob_boxplot <- function(aesthetics, breaks=length(unique(aesthetics$x)), ...) {
+	aesthetics <- aesdefaults(aesthetics, list(fill="white", colour="grey50"), ...)
+	
 	aesthetics$x <- as.numeric(aesthetics$x)
+	n <- length(aesthetics$x)
 	breakpoints <- cut(aesthetics$x, breaks, labels=FALSE)
 	xrange <- list(
-		min = tapply(aesthetics$x, breakpoints, min, na.rm=TRUE),
-		max = tapply(aesthetics$x, breakpoints, max, na.rm=TRUE),
+		min =    tapply(aesthetics$x, breakpoints, min, na.rm=TRUE),
+		max =    tapply(aesthetics$x, breakpoints, max, na.rm=TRUE),
 		median = tapply(aesthetics$x, breakpoints, median, na.rm=TRUE),
-		width = tapply(aesthetics$x, breakpoints, function(x) diff(range(x, na.rm=TRUE))) * 0.5 + 0.5,
+		width =  tapply(aesthetics$x, breakpoints, function(x) diff(range(x, na.rm=TRUE))) * 0.5 + 0.5,
+		colour = tapply(rep(aesthetics$colour,length=n), breakpoints, function(x) x[1]),
+		fill =   tapply(rep(aesthetics$fill,  length=n), breakpoints, function(x) x[1]),
 	)
 	
 	boxes <- boxplot(aesthetics$y ~ breakpoints, plot=FALSE, ...)
 	# lower whisker, lower hinge, median, upper hinge and upper whisker
 	
 	outliers <- list(y = boxes$out, x = as.vector(xrange$median[boxes$group]), colour="red")
-	uwhiskers <- list(y = c(boxes$stats[1,], boxes$stats[2, ]), x=rep(xrange$median, 2), id=rep(xrange$median, 2))
-	lwhiskers <- list(y = c(boxes$stats[4,], boxes$stats[5, ]), x=rep(xrange$median, 2), id=rep(xrange$median, 2))
-	hinges <- list(x = xrange$median, width=xrange$width, y=boxes$stats[2,], height=boxes$stats[4,] - boxes$stats[2,], fill="white", colour="grey50")
-	medians <- list(x= xrange$median, width=xrange$width, y=boxes$stats[3,], height=unit(0.8,"mm"), colour="grey50", fill="grey50")
+	uwhiskers <- list(y = c(boxes$stats[1,], boxes$stats[2, ]), x=rep(xrange$median, 2), id=rep(xrange$median, 2),  colour=xrange$colour)
+	lwhiskers <- list(y = c(boxes$stats[4,], boxes$stats[5, ]), x=rep(xrange$median, 2), id=rep(xrange$median, 2),  colour=xrange$colour)
+	hinges <- list(x = xrange$median, width=xrange$width, y=boxes$stats[2,], height=boxes$stats[4,] - boxes$stats[2,], fill=xrange$fill, colour=xrange$colour)
+	medians <- list(x= xrange$median, width=xrange$width, y=boxes$stats[3,], height=unit(0.8,"mm"), colour=xrange$colour, fill=xrange$colour)
 	
 	gTree(children = gList(
 		grob_path(uwhiskers),
@@ -192,10 +206,10 @@ grob_boxplot <- function(aesthetics, breaks=length(unique(aesthetics$x)), ...) {
 # Aesthetic mappings that this grob function understands:
 #
 # \itemize{
-#   \item x: x position (required)
-#   \item y: y position (required)
-#   \item size: size of the point, in mm (see \code{\link{scsize})}
-#   \item colour: point colour (see \code{\link{sccolour})}
+#   \item \code{x}:x position (required)
+#   \item \code{y}:y position (required)
+#   \item \code{size}:size of the point, in mm (see \code{\link{scsize})}
+#   \item \code{colour}:point colour (see \code{\link{sccolour})}
 # }
 # 
 # These can be specified in the plot defaults (see \code{\link{ggplot}}) or
@@ -207,9 +221,9 @@ grob_boxplot <- function(aesthetics, breaks=length(unique(aesthetics$x)), ...) {
 # Other options:
 # 
 # \itemize{
-#   \item method: smoothing method (function) to use
-#   \item formula: formula to use in smoothing function
-#   \item se: display one standard error on either side of fit? (true by default)
+#   \item \code{method}:smoothing method (function) to use
+#   \item \code{formula}:formula to use in smoothing function
+#   \item \code{se}:display one standard error on either side of fit? (true by default)
 #   \item other arguments are passed to smoothing function
 # }
 # 
@@ -224,12 +238,12 @@ grob_boxplot <- function(aesthetics, breaks=length(unique(aesthetics$x)), ...) {
 #X ggsmooth(p, method=lm)
 #X ggsmooth(p, method=lm, formula = y~splines::ns(x,3))
 #X ggsmooth(p, method=MASS::rlm, formula = y~splines::ns(x,3))
-ggsmooth <- function(plot = .PLOT, aesthetics=list(), ..., data=plot$data) {
+ggsmooth <- function(plot = .PLOT, aesthetics=list(), ..., data=NULL) {
 	gg_add("smooth", plot, aesthetics, ..., data=data)
 }
 grob_smooth <- function(aesthetics, method=loess, formula=y~x, se = TRUE, ...) {
-	aesthetics <- defaults(aesthetics, list(colour="black", size=1, ))
-	xseq <- seq(min(aesthetics$x, na.rm=TRUE), max(aesthetics$x, na.rm=TRUE), length=30)
+	aesthetics <- aesdefaults(aesthetics, list(colour="black", size=1), ...)
+	xseq <- seq(min(aesthetics$x, na.rm=TRUE), max(aesthetics$x, na.rm=TRUE), length=80)
 	method <- match.fun(method)
 
 	colour <- as.character(uniquedefault(aesthetics$colour, "black"))
@@ -241,8 +255,9 @@ grob_smooth <- function(aesthetics, method=loess, formula=y~x, se = TRUE, ...) {
 	if (se) {
 		gTree(children=gList(
 			grob_path(list(y = as.vector(pred$fit), x = xseq, colour=colour, size=size)),
-			grob_path(list(y = as.vector(pred$fit + pred$se), x = xseq, colour="grey80")),
-			grob_path(list(y = as.vector(pred$fit - pred$se), x = xseq, colour="grey80"))
+			grob_path(list(y = as.vector(pred$fit + 2 * pred$se), x = xseq, colour="grey80")),
+			grob_path(list(y = as.vector(pred$fit - 2 * pred$se), x = xseq, colour="grey80")),
+			grob_ribbon(list(y = c(pred$fit + 2 * pred$se, rev(pred$fit - 2 * pred$se)), x = c(xseq,rev(xseq))), colour=NA, fill=alpha("grey50", 0.2))
 		))
 	} else {
 		grob_path(list(y = as.vector(pred), x = xseq, colour=colour, size=size))
@@ -255,9 +270,9 @@ grob_smooth <- function(aesthetics, method=loess, formula=y~x, se = TRUE, ...) {
 # Aesthetic mappings that this grob function understands:
 #
 # \itemize{
-#   \item x: x position (required)
-#   \item y: y position (required)
-#   \item z: z position (required)
+#   \item \code{x}:x position (required)
+#   \item \code{y}:y position (required)
+#   \item \code{z}:z position (required)
 # }
 # 
 # These can be specified in the plot defaults (see \code{\link{ggplot}}) or
@@ -269,8 +284,9 @@ grob_smooth <- function(aesthetics, method=loess, formula=y~x, se = TRUE, ...) {
 # Other options:
 # 
 # \itemize{
-#   \item nlevels: number of contours to draw
-#   \item levels: contour positions
+#   \item \code{nlevels}: number of contours to draw
+#   \item \code{levels}: contour positions
+# 	\item \code{...}: other aesthetic parameters passed to \code{\link{grob_path}}
 # }
 # 
 # @arguments the plot object to modify
@@ -282,12 +298,13 @@ grob_smooth <- function(aesthetics, method=loess, formula=y~x, se = TRUE, ...) {
 #X volcano3d <- data.frame(expand.grid(x = 1:nrow(volcano), y=1:ncol(volcano)), z=as.vector(volcano))
 #X p <- ggplot(volcano3d, aesthetics=list(x=x,y=y,z=z))
 #X ggcontour(p)
+#X ggcontour(p, colour="red")
 #X ggcontour(p, nlevels=3)
-#X ggcontour(ggtile(p, list(colour=z)))
-ggcontour <- function(plot = .PLOT, aesthetics=list(), ..., data=plot$data) {
+#X ggcontour(ggtile(p, list(fill=z)))
+ggcontour <- function(plot = .PLOT, aesthetics=list(), ..., data=NULL) {
 	gg_add("contour", plot, aesthetics, ..., data=data)
 }
-grob_contour <- function(aesthetics, nlevels=10, levels) {
+grob_contour <- function(aesthetics, nlevels=10, levels, ...) {
 	if (missing(levels)) levels <- pretty(range(aesthetics$z,na.rm=TRUE),nlevels)
 	gridise <- function(x) {
 		unique <- sort(unique(x[!is.na(x)]))
@@ -302,14 +319,72 @@ grob_contour <- function(aesthetics, nlevels=10, levels) {
 	gridz[(gridy$id - 1) * length(gridx$unique) + gridx$id] <- aesthetics$z
 	
 	clines <- contourLines(x = gridx$unique, y = gridy$unique, z = gridz, nlevels = nlevels, levels = levels)
-	clines <- lapply(clines, function(x) {
-	  x$colour <- "blue"
-	  x
-	})
 		
-	gTree(children = do.call(gList, lapply(clines, grob_path)))
+	gTree(children = do.call(gList, lapply(clines, grob_path, ...)))
 }
 
+
+# Grob function: 1d density
+# Display a smooth density estimate.
+# 
+# Aesthetic mappings that this grob function understands:
+#
+# \itemize{
+#   \item \code{x}:x position (required)
+# }
+# 
+# These can be specified in the plot defaults (see \code{\link{ggplot}}) or
+# in the \code{aesthetics} argument.  If you want to modify the position 
+# of the points or any axis options, you will need to add a position scale to
+# the plot.  These functions start with \code{ps}, eg. 
+# \code{\link{pscontinuous}} or \code{\link{pscategorical}}
+# 
+# Other options:
+# 
+# \itemize{
+#   \item \code{adjust}: see \code{\link{density}}
+# 		for details
+# 	\item \code{kernel}: kernel used for density estimation, see \code{\link{density}}
+# 		for details
+# 	\item other aesthetic properties passed on to \code{\link{ggline}}
+# }
+# 
+# @arguments the plot object to modify
+# @arguments named list of aesthetic mappings, see details for more information
+# @arguments other options, see details for more information
+# @arguments data source, if not specified the plot default will be used
+# @keyword hplot
+# @seealso \code{\link{gghistogram}}, \code{\link{density}}
+#X m <- ggplot(movies, aesthetics=list(x=rating))
+#X ggdensity(m)
+#X qplot(length, data=movies, type="density")
+#X qplot(length, data=movies, type="density", log="x")
+#X qplot(log(length), data=movies, type="density")
+#X m <- ggplot(movies, Action ~ Comedy, aesthetics=list(x=rating), margins=TRUE)
+#X ggdensity(m)
+#X ggdensity(m, scale="freq")
+#X ggdensity(m, colour="darkgreen", size=5) 
+ggdensity <- function(plot = .PLOT, aesthetics=list(), ..., data=NULL) {
+	plot$ylabel <- "Density"
+	plot <- pscontinuous(plot, "y", range=c(0,NA), expand=c(0.05,0))
+	gg_add("density", plot, aesthetics, ..., data=data)
+}  
+pre_density <- function(data, adjust=1, kernel="gaussian", ...) {
+	dens <- density(data$x, adjust=adjust, kernel=kernel)
+	dens$'.type' <- "density"
+
+	rug <- data.frame(x = jitter(data$x), y=-0.5, .type="rug")
+	rbind(as.data.frame(dens[c("x","y",".type")]), rug)
+}
+grob_density <- function(aesthetics, ...) {
+	aesthetics <- data.frame(aesthetics)
+	dens <- subset(aesthetics, .type == "density")
+	rug <- subset(aesthetics, .type == "rug")
+
+	grob_line(dens, ...)
+}
+
+
 # Grob function: 2d density
 # Perform a 2D kernel density estimatation using \code{\link{kde2d}} and
 # display the results with contours.
@@ -319,8 +394,8 @@ grob_contour <- function(aesthetics, nlevels=10, levels) {
 # Aesthetic mappings that this grob function understands:
 #
 # \itemize{
-#   \item x: x position (required)
-#   \item y: y position (required)
+#   \item \code{x}:x position (required)
+#   \item \code{y}:y position (required)
 # }
 # 
 # These can be specified in the plot defaults (see \code{\link{ggplot}}) or
@@ -347,7 +422,7 @@ grob_contour <- function(aesthetics, nlevels=10, levels) {
 #X ggcontour(m, list(z=z), data=densdf)
 #X gg2density(m)
 #X # they don't look the same due to scaling effects on kde2d
-gg2density <- function(plot = .PLOT, aesthetics=list(), ..., data=plot$data) {
+gg2density <- function(plot = .PLOT, aesthetics=list(), ..., data=NULL) {
 	gg_add("2density", plot, aesthetics, ..., data=data)
 }
 
@@ -371,9 +446,9 @@ grob_2density <- function(aesthetics, ...) {
 # Aesthetic mappings that this grob function understands:
 #
 # \itemize{
-#   \item x: x position (required)
-#   \item y: y position (required)
-#   \item id: 
+#   \item \code{x}:x position (required)
+#   \item \code{y}:y position (required)
+#   \item \code{id}:
 #   \item any other grobs used by the grob function you choose
 # }
 # 
@@ -386,9 +461,9 @@ grob_2density <- function(aesthetics, ...) {
 # Other options:
 # 
 # \itemize{
-#   \item grob: grob function to use for subgroups
+#   \item \code{grob}:grob function to use for subgroups
 #   \item anything else used by the grob function you choose
-# }
+# } 
 # 
 # @arguments the plot object to modify
 # @arguments named list of aesthetic mappings, see details for more information
@@ -399,7 +474,7 @@ grob_2density <- function(aesthetics, ...) {
 #X gggroup(p)
 #X gggroup(ggpoint(p), grob=grob_smooth, se=FALSE, span=1)
 #X gggroup(ggpoint(p), aes=list(id=cyl, size=cyl), grob=grob_smooth, span=1)
-gggroup <- function(plot = .PLOT, aesthetics=list(), ..., data=plot$data) {
+gggroup <- function(plot = .PLOT, aesthetics=list(), ..., data=NULL) {
 	gg_add("group", plot, aesthetics, ..., data=data)
 }
 grob_group <- function(aesthetics, grob = grob_point, ...) {
@@ -420,8 +495,8 @@ grob_group <- function(aesthetics, grob = grob_point, ...) {
 # Aesthetic mappings that this grob function understands:
 #
 # \itemize{
-#   \item x: x position (required)
-#   \item y: y position (required)
+#   \item \code{x}:x position (required)
+#   \item \code{y}:y position (required)
 # }
 # 
 # These can be specified in the plot defaults (see \code{\link{ggplot}}) or
@@ -433,8 +508,8 @@ grob_group <- function(aesthetics, grob = grob_point, ...) {
 # Other options:
 # 
 # \itemize{
-#   \item xbins: number of bins to use
-#   \item ...: other arguments passed to \code{\link[hexbin]{grid.hexagons}}
+#   \item \code{xbins}:number of bins to use
+#   \item \code{...}:other arguments passed to \code{\link[hexbin]{grid.hexagons}}
 # }
 # 
 # @keyword hplot 
@@ -447,16 +522,13 @@ grob_group <- function(aesthetics, grob = grob_point, ...) {
 #X gghexagon(m)
 #X gghexagon(m, xbins=50)
 #X gghexagon(m, style="lattice")
-gghexagon <- function(plot = .PLOT, aesthetics=list(), ..., data=plot$data) {
+gghexagon <- function(plot = .PLOT, aesthetics=list(), ..., data=NULL) {
 	gg_add("hexagon", plot, aesthetics, ..., data=data)
 }
 grob_hexagon <- function(aesthetics, xbins=30, ...) {
 	if (!require("hexbin", quietly=TRUE)) stop("You need to install the hexbin package !")
 	
 	hexes <- hexbin(aesthetics$x, aesthetics$y, xbins=xbins)
-	#grobs <- grid.grabExpr(grid.hexagons(hexes, ...))
-	
-	gTree(children=gList(hexagonsGrob(hexes, ...)))
-}
-
 
+	grid.grabExpr(grid.hexagons(hexes, ...))
+}
\ No newline at end of file
